About `gpx_vis`
===============

`gpx_vis` allows simple and easy visualisation of your cycling/walking tours.

Important: currently only works for .GPX from completed paths in Komoot. In development.

Install
-------

```bash
pip install gpx_vis
```

Update to the latest version:

```bash
pip install gpx_vis --upgrade
```

Instantiate
-----------

```python
from gpx_vis import Track

track = Track(pathname)
```

`pathname` serves as a reference to either a single `.gpx` file or a directory.
If a directory path is provided, all .gpx files contained within that directory
will be merged, but retain their original metadata (e.g., different tracks remain separated).
This allows users to overlay multiple tracks onto a single map, 
providing a comprehensive summary of the data being analyzed or created.

Map creation
------------

```python
track.create_map(path2file)
```

This creates an html file saved to `path2file`. An interactive html map will be created.
Hover mouse over route, or click on final waypoints (flag marker) for further info.

Route (Matplotlib)
------------------

```python
track.plt_tracks()
```

Creates a latitude-longitude plot with matplotlib, colourmaped by elevation.

City overview
-------------

```python
track.city_list
```

Curious which city you went through along the way? This command creates a list
of cities - sorted by country then name - that were detected through the tour. The 
`frequency` parameter tells how many times a city was encountered; it should 
somewhat correlate to time spent in that city.

Additional information
----------------------

Shoud you wish to plot/inspect different values, these parameters are also accesssible via:  

`track.t`: time
`track.x`: longitude
`track.y`: latitude
`track.z`: elevation
